@@ -58,7 +58,7 @@ def parse(octets):
     return match_prefix.groups(), params[0], params[1:]
 
 class ThreadSafeEnvironment(object):
-    def __init__(self, saxo, prefix, command, parameters):
+    def __init__(self, saxo, prefix, command, parameters, identified):
         self.base = saxo.base[:]
         self.config = saxo.config_cache.copy()
 
@@ -71,10 +71,14 @@ class ThreadSafeEnvironment(object):
 
         self.command = command
         self.parameters = parameters
+        self.identified = identified
 
         if command == "PRIVMSG":
             self.sender = self.parameters[0]
-            self.text = self.parameters[1]
+            if self.identified:
+               self.text = self.parameters[1][1:]
+            else:
+               self.text = self.parameters[1]
             self.private = self.sender == self.config["nick"]
             if self.private:
                 self.sender = self.nick
@@ -151,6 +155,7 @@ class Saxo(object):
         self.receiving = False
         self.sending = False
         self.user_reconnection = False
+        self.identify_msg = False
         self.links = {}
 
         self.environment_cache = os.environ.copy()
@@ -267,6 +272,7 @@ class Saxo(object):
                 try: method(*args)
                 except Exception as err:
                     debug("handle error:", err)
+                    # raise err # - for debug
             else:
                 debug("Unknown instruction:", instruction)
 
@@ -275,8 +281,12 @@ class Saxo(object):
 
     def instruction_connected(self):
         if ":connected" in self.events:
+            irc = ThreadSafeEnvironment(self, ("", "", ""), "", [], None)
             for function in self.events[":connected"]:
-                function(self, None, None)
+                function(irc)
+
+    def instruction_command(self, prefix, sender, cmd, arg):
+        self.command(prefix, sender, cmd, arg)
 
     def instruction_disco_receiving(self):
         self.receiving = False
@@ -295,6 +305,9 @@ class Saxo(object):
                 # TODO: Close the socket?
                 ...
 
+    def instruction_identify_msg(self, ack):
+        self.identify_msg = ack
+
     def instruction_join(self, channel):
         # NOTE: .visit can still be followed by .join
         # The JOIN will just fail on the server
@@ -356,6 +369,9 @@ class Saxo(object):
 
     def instruction_receiving(self):
         self.receiving = True
+        # TODO: Check that we really are connected
+        # TODO: Unit test for :connected event
+        incoming.put(("connected",))
 
     def instruction_reconnect(self, close=True):
         if close:
@@ -363,10 +379,11 @@ class Saxo(object):
             # Never call this from a thread, otherwise this can give an OSError
             self.disconnect()
 
-        if not self.opt["client"]["flood"]:
+        flood = "flood" in self.opt["client"]
+        if not flood:
             time.sleep(3)
         for attempt in range(7):
-            if not self.opt["client"]["flood"]:
+            if not flood:
                 if self.receiving or self.sending:
                     time.sleep(1)
                 # TODO: If the threads are still active, they should be killed
@@ -387,9 +404,15 @@ class Saxo(object):
     def instruction_remote(self, octets):
         debug(repr(octets))
         prefix, command, parameters = parse(octets)
+        identified = None
 
         if command == "PRIVMSG":
-            privmsg = parameters[1]
+            if self.identify_msg:
+                identified = parameters[1][0] is "+"
+                privmsg = parameters[1][1:]
+            else:
+                privmsg = parameters[1]
+
             pfx = self.opt["client"]["prefix"]
             length = len(pfx)
 
@@ -404,7 +427,7 @@ class Saxo(object):
                 if sender == self.opt["client"]["nick"]:
                     sender = prefix[0]
 
-                self.command(prefix, sender, cmd, arg)
+                self.command(prefix, sender, identified, cmd, arg)
 
         elif command == "PONG":
             if self.discotimer is not None:
@@ -415,7 +438,9 @@ class Saxo(object):
                 except:
                     ...
 
-        irc = ThreadSafeEnvironment(self, prefix, command, parameters)
+
+        args = (self, prefix, command, parameters, identified)
+        irc = ThreadSafeEnvironment(*args)
         def safe(function, irc):
             try: function(irc)
             except Exception as err:
@@ -446,7 +471,7 @@ class Saxo(object):
     def instruction_sending(self):
         self.sending = True
 
-    def command(self, prefix, sender, cmd, arg):
+    def command(self, prefix, sender, identified, cmd, arg):
         if ("\x00" in cmd) or (os.sep in cmd) or ("." in cmd):
             return
 
@@ -463,10 +488,11 @@ class Saxo(object):
                 # Might have been removed just after running this thread
                 return
             else:
-                try: outs, errs = proc.communicate(octets + b"\n", timeout=6)
+                try: outs, errs = proc.communicate(octets + b"\n", timeout=12)
                 except subprocess.TimeoutExpired:
                     proc.kill()
-                    outs = "Sorry, .%s took too long" % cmd
+                    # TODO: Use actual prefix
+                    outs = "Sorry, %s took too long" % cmd
                 else:
                     outs = outs.decode("utf-8", "replace")
                     if "\n" in outs:
@@ -475,7 +501,8 @@ class Saxo(object):
                 code = proc.returncode or 0
                 # Otherwise: TypeError: unorderable types: NoneType() > int()
                 if (code > 0) and (not outs):
-                    outs = "Sorry, .%s responded with an error" % cmd
+                    # TODO: Use actual prefix
+                    outs = "Sorry, %s responded with an error" % cmd
 
             if outs:
                 self.send("PRIVMSG", sender, outs)
@@ -484,6 +511,10 @@ class Saxo(object):
             env = self.environment_cache.copy()
             env["SAXO_NICK"] = prefix[0]
             env["SAXO_SENDER"] = sender
+            if identified == True:
+                env["SAXO_IDENTIFIED"] = "1"
+            if identified == False:
+                env["SAXO_IDENTIFIED"] = "0"
             if sender in self.links:
                 env["SAXO_URL"] = self.links[sender]
             common.thread(process, env, path, arg)
@@ -538,31 +569,28 @@ def serve(sockname, incoming):
             common.thread(handle, connection, client)
     common.thread(listen, sock)
 
-E_NO_PLUGINS = """
-The plugins directory is necessary for saxo to work. If it was deleted
-accidentally, just make a new empty directory and saxo will automatically
-populate it with the core plugin that it needs to work.
+E_NO_CONFIG = """
+Are you sure this is a saxo configuration directory? If you need to make a new
+configuration directory, use the `saxo create` command.
 """
 
 def start(base):
     # TODO: Check when two clients are running
     common.exit_cleanly()
     # http://stackoverflow.com/questions/11423225
-    signal.signal(signal.SIGPIPE, signal.SIG_DFL)
-
-    plugins = os.path.join(base, "plugins")
-    if not os.path.isdir(plugins):
-        common.error("no plugins directory: `%s`" % plugins, E_NO_PLUGINS)
-
-    # TODO: Check for broken symlinks
-    common.populate(saxo_path, base)
+    # IGN rather than DFL, otherwise Popen.communicate can quit saxo
+    signal.signal(signal.SIGPIPE, signal.SIG_IGN)
 
     opt = configparser.ConfigParser(interpolation=None)
     config = os.path.join(base, "config")
+    if not os.path.isfile(config):
+        error("missing config file in: `%s`" % config, E_NO_CONFIG)
     opt.read(config)
     # TODO: Defaulting?
     # TODO: Warn if the config file is widely readable?
 
+    common.populate(saxo_path, base)
+
     sockname =  os.path.join(base, "client.sock")
     serve(sockname, incoming)
     os.chmod(sockname, 0o600)
